$rabbit_user = "deploytracker"
$rabbit_vhost = "deploytracker"
$rabbit_host = "localhost"
$rabbit_port = "5672"

$wsgi_user = "deploytracker"
$wsgi_processes = 2
$wsgi_threads = 2

$postgres_user = "deploytracker"
$postgres_database = "deploytracker"
$postgres_host = "localhost"
$postgres_port = "5432"

$unix_user = "deploytracker"

$py = "$::basedir/py"

group {$unix_user:
   ensure => 'present',
}

user {$unix_user:
   comment => 'This user was created by Puppet',
   ensure => 'present',
   gid => $unix_user,
   require => Group[$unix_user],
}

exec { "psql-create-user-$postgres_user":
  command => "psql -c \"create user $postgres_user with password '$::postgres_password'\"",
  path => ["/usr/bin", "/bin"],
  user => "postgres",
  unless => "psql -c \"select usename from pg_user where usename = '$postgres_user'\" | grep -q $postgres_user",
}

exec { "psql-create-database-$postgres_database":
  command => "psql -c 'create database $postgres_database owner $postgres_user'",
  path => ["/usr/bin", "/bin"],
  user => "postgres",
  require => Exec["psql-create-user-$postgres_user"],
  unless => "psql -c \"select datname from pg_database where datname = '$postgres_database'\" | grep -q $postgres_database",
}

exec { "psql-grant-all-$postgres_database-$postgres_user":
  command => "psql -c 'grant all privileges on database $postgres_database to $postgres_user'",
  path => ["/usr/bin"],
  user => "postgres",
  require => Exec["psql-create-database-$postgres_database"],
}

file { "$::basedir/django_project/local_settings.py":
  content => template("local_settings.py.erb"),
  owner => $unix_user,
  group => $unix_user,
  mode => 640,
  require => [
      Group[$unix_user],
      Exec["psql-grant-all-$postgres_database-$postgres_user"],
  ],
}

file { "$py":
  content => template("py.erb"),
  owner => $unix_user,
  group => $unix_user,
  mode => 750,
  require => [
      Group[$unix_user],
  ],
}

file { "$::basedir/django.log":
  owner => $unix_user,
  group => $unix_user,
  mode => 644,
  ensure => present,
}

file { "$::basedir/oopses":
  owner => $unix_user,
  group => $unix_user,
  mode => 755,
  ensure => directory,
}

file { "$::basedir/static/":
  owner => $unix_user,
  group => $unix_user,
  mode => 755,
  ensure => directory,
}

file { "$::basedir/branches/":
  owner => $unix_user,
  group => $unix_user,
  mode => 755,
  ensure => directory,
}

file { "$::basedir/celery.log":
  owner => $unix_user,
  group => $unix_user,
  mode => 644,
  ensure => present,
}

file { "$::basedir/celery.pid":
  owner => $unix_user,
  group => $unix_user,
  mode => 644,
  ensure => present,
}

exec { "django-syncdb":
  command => "$py ./manage.py syncdb --noinput",
  cwd => "$::basedir/django_project",
  path => ["/usr/bin"],
  user => $unix_user,
  require => [
              File["$py"],
              File["$::basedir/django_project/local_settings.py"],
              File["$::basedir/django.log"],
             ],
  logoutput => on_failure,
  loglevel => err,
}

exec { "django-migrate":
  command => "$py ./manage.py migrate",
  cwd => "$::basedir/django_project",
  path => ["/usr/bin"],
  user => $unix_user,
  require => [
              File["$py"],
              Exec["django-syncdb"],
             ],
  logoutput => on_failure,
}

exec { "django-collectstatic":
  command => "$py ./manage.py collectstatic --noinput",
  cwd => "$::basedir/django_project",
  path => ["/usr/bin"],
  user => $unix_user,
  require => [
              File["$py"],
              Exec["django-migrate"],
              File["$::basedir/static/"],
             ],
  logoutput => on_failure,
}

file { "$::basedir/django_project/django.wsgi":
  content => template("django.wsgi.erb"),
  require => [
    File["$::basedir/django_project/local_settings.py"],
  ]
}

exec { "enable-mod-expires":
  user => root,
  command => "/usr/sbin/a2enmod expires",
  unless => "/usr/bin/stat -t /etc/apach2/mods-enabled/expires.load",
}

exec { "enable-mod-headers":
  user => root,
  command => "/usr/sbin/a2enmod headers",
  unless => "/usr/bin/stat -t /etc/apach2/mods-enabled/headers.load",
}

file { "/etc/apache2/httpd.conf":
  content => template("httpd.conf.erb"),
  require => [
    Exec["enable-mod-expires"],
    Exec["enable-mod-headers"],
  ]
}

exec { "/etc/init.d/apache2 reload":
  user => root,
  require => [
    File["/etc/apache2/httpd.conf"],
    File["$::basedir/django_project/django.wsgi"],
  ],
}

$celeryd_default_file = "/etc/default/deploy-tracker-celeryd"

file { "/etc/init.d/deploy-tracker-celeryd":
  content => template("celeryd.initscript.erb"),
  mode => 755,
  owner => root,
}

file { $celeryd_default_file:
  content => template("celeryd.default.erb"),
  owner => root,
  mode => 644,
}

exec { "rabbit-add-user-$rabbit_user":
  command => "rabbitmqctl add_user $rabbit_user $::rabbit_password",
  path => ["/usr/sbin", "/bin", "/usr/bin"],
  user => root,
  unless => "rabbitmqctl list_users | grep -q \"\\<$rabbit_user\\>\"",
}

exec { "rabbit-add-vhost-$rabbit_vhost":
  command => "rabbitmqctl add_vhost $rabbit_vhost",
  path => ["/usr/sbin", "/bin", "/usr/bin"],
  user => root,
  unless => "rabbitmqctl list_vhosts | grep -q \"\\<$rabbit_vhost\\>\"",
}

exec { "rabbit-set-permissions-$rabbit_vhost-$rabbit_user":
  command => "rabbitmqctl set_permissions -p $rabbit_vhost $rabbit_user .\\* .\\* .\\*",
  path => ["/usr/sbin", "/bin", "/usr/bin"],
  user => root,
  require => [
    Exec["rabbit-add-user-$rabbit_user"],
    Exec["rabbit-add-vhost-$rabbit_vhost"],
  ],
  unless => "rabbitmqctl list_permissions -p $rabbit_vhost | grep -q \"^\\<$rabbit_user\\>\"",
}

service { "deploy-tracker-celeryd":
  ensure => running,
  hasrestart => true,
  hasstatus => true,
  subscribe => [
     File['/etc/init.d/deploy-tracker-celeryd'],
     File[$celeryd_default_file],
  ],
  require => [
     File["$py"],
     File["$::basedir/celery.log"],
     File["$::basedir/celery.pid"],
  ],
}
